function [ f_ion ] = create_ion_spectrum( p, pk, fk, w1, w2, alpha )
% -------------------------------------------------------------------------
%
% NAME
%
%	create_ion_spectrum
%
% PURPOSE
%
%	This routine creates an ion spectrum (ion beam profile) with the prescribed
%   peak parameters, for ion peaks with intensity fk at positions pk.
%
% CALLING SEQUENCE
%
%	[ f_ion ] = create_ion_spectrum( p, pk, fk, w1, w2, alpha )
%
% INPUT PARAMETERS
%   
%   p
%     pixel vector
%
%   pk
%     positions of the centres of the ion beams
%
%   fk
%     peak ion fluxes, same format as pk
%
%   w1, w2, alpha
%     half-widths of both Gaussian components and relative importance of
%     the secondary Gaussian
%
% OUTPUT PARAMETERS
%
%   f_ion
%     ion spectrum (ion beam profile), same format as p
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------
    
    % create ion spectrum
    f_ion = 0*p;
    
    % add peak for each ion species
    for i = 1:length(pk)
        f_ion = f_ion + ion_beam( p, pk(i), fk(i), w1, w2, alpha );
    end

end

% =========================================================================
