function [ A ] = double_gaussian_area( w1, w2, alpha )
% -------------------------------------------------------------------------
%
% NAME
%
%	double_gaussian_area
%
% PURPOSE
%
%	This routine computes the integral of a double Gaussian with the prescribed parameters.
%
% CALLING SEQUENCE
%
%	[ A ] = double_gaussian_area( w1, w2, alpha )
%
% INPUT PARAMETERS
%   
%   w1, w2, alpha
%     half-widths of both Gaussian components and relative importance of
%     the secondary Gaussian
%
% OUTPUT PARAMETERS
%
%   A
%     double, integral of the gaussian profile
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------

    A = sqrt(pi) * ( ( 1 - alpha ) * w1 + alpha * w2 );

end

% =========================================================================
